pub enum GivenClause {
Input {
fields: Vec<TestField>,
span: SourceSpan,
},
Fact {
ty: Ident,
fields: Vec<TestField>,
span: SourceSpan,
},
Signal {
name: String,
fields: Vec<TestField>,
span: SourceSpan,
},
Clock {
at: StringLiteral,
span: SourceSpan,
},
Tracker {
tracker: String,
fields: Vec<TestField>,
span: SourceSpan,
},
File {
store: String,
path: StringLiteral,
content: StringLiteral,
span: SourceSpan,
},
}Variants
Input
Fact
Signal
Clock
Tracker
File
given file <store> at <path> "<content>" seeds a fixture file in the
named file store so a read during whip test resolves deterministic
content (the harness redirects the store root to a temp dir).