pub fn compile_program_with_root(
source: &str,
root: Option<&str>,
) -> CompileOutputExpand description
Parses and lowers a source bundle into deterministic typed IR with an optional explicit root workflow selection.
pub fn compile_program_with_root(
source: &str,
root: Option<&str>,
) -> CompileOutputParses and lowers a source bundle into deterministic typed IR with an optional explicit root workflow selection.