pub fn format_program(source: &str) -> FormatOutputExpand description
Formats the syntax tree without lowering or analyzing rule bodies.
pub fn format_program(source: &str) -> FormatOutputFormats the syntax tree without lowering or analyzing rule bodies.