lex_comments

Function lex_comments 

pub fn lex_comments(source: &str) -> Vec<Comment>
Extract the comments from a source program, in source order. Comments are not part of the token stream or AST; this is the entry point tooling (whip fmt, the LSP) uses to preserve them.