pub fn document_symbols(source: &str) -> Vec<DeclSymbol>Expand description
Top-level declarations of source in source order, for an editor outline. On a
parse error it returns whatever declarations parsed (best-effort outline).
pub fn document_symbols(source: &str) -> Vec<DeclSymbol>Top-level declarations of source in source order, for an editor outline. On a
parse error it returns whatever declarations parsed (best-effort outline).